@@ -167,7 +167,8 @@ class TestAvailability(unittest.TestCase):
 
     def test_proc_memory_maps(self):
         hasit = hasattr(psutil.Process, "memory_maps")
-        self.assertEqual(hasit, False if OPENBSD or NETBSD or AIX else True)
+        self.assertEqual(
+            hasit, False if OPENBSD or NETBSD or AIX or MACOS else True)
 
 
 # ===================================================================
@@ -181,7 +182,7 @@ class TestDeprecations(unittest.TestCase):
         with warnings.catch_warnings(record=True) as ws:
             psutil.Process().memory_info_ex()
         w = ws[0]
-        self.assertIsInstance(w.category(), FutureWarning)
+        self.assertIsInstance(w.category(), DeprecationWarning)
         self.assertIn("memory_info_ex() is deprecated", str(w.message))
         self.assertIn("use memory_info() instead", str(w.message))
 
@@ -294,7 +295,8 @@ class TestFetchAllProcesses(unittest.TestCase):
         valid_procs = 0
         excluded_names = set([
             'send_signal', 'suspend', 'resume', 'terminate', 'kill', 'wait',
-            'as_dict', 'parent', 'children', 'memory_info_ex', 'oneshot',
+            'as_dict', 'parent', 'parents', 'children', 'memory_info_ex',
+            'oneshot',
         ])
         if LINUX and not HAS_RLIMIT:
             excluded_names.add('rlimit')
