@@ -200,8 +200,8 @@ class TestProcessObjectLeaks(TestMemLeak):
         skip = set((
             "pid", "as_dict", "children", "cpu_affinity", "cpu_percent",
             "ionice", "is_running", "kill", "memory_info_ex", "memory_percent",
-            "nice", "oneshot", "parent", "rlimit", "send_signal", "suspend",
-            "terminate", "wait"))
+            "nice", "oneshot", "parent", "parents", "rlimit", "send_signal",
+            "suspend", "terminate", "wait"))
         for name in dir(psutil.Process):
             if name.startswith('_'):
                 continue
@@ -344,8 +344,6 @@ class TestProcessObjectLeaks(TestMemLeak):
         with open(TESTFN, 'w'):
             self.execute(self.proc.open_files)
 
-    # MACOS implementation is unbelievably slow
-    @unittest.skipIf(MACOS, "too slow on MACOS")
     @unittest.skipIf(not HAS_MEMORY_MAPS, "not supported")
     @skip_if_linux()
     def test_memory_maps(self):
@@ -384,6 +382,16 @@ class TestProcessObjectLeaks(TestMemLeak):
         self.execute(cext.proc_info, os.getpid())
 
 
+class TestProcessDualImplementation(TestMemLeak):
+
+    if WINDOWS:
+        def test_cmdline_peb_true(self):
+            self.execute(cext.proc_cmdline, os.getpid(), use_peb=True)
+
+        def test_cmdline_peb_false(self):
+            self.execute(cext.proc_cmdline, os.getpid(), use_peb=False)
+
+
 class TestTerminatedProcessLeaks(TestProcessObjectLeaks):
     """Repeat the tests above looking for leaks occurring when dealing
     with terminated processes raising NoSuchProcess exception.
@@ -524,6 +532,7 @@ class TestModuleFunctionsLeaks(TestMemLeak):
 
     # --- net
 
+    @unittest.skipIf(TRAVIS and MACOS, "false positive on travis")
     @skip_if_linux()
     def test_net_io_counters(self):
         self.execute(psutil.net_io_counters, nowrap=False)
