@@ -288,7 +288,7 @@ class TestProcess(unittest.TestCase):
         failures = []
         ignored_names = ['terminate', 'kill', 'suspend', 'resume', 'nice',
                          'send_signal', 'wait', 'children', 'as_dict',
-                         'memory_info_ex']
+                         'memory_info_ex', 'parent', 'parents']
         if LINUX and get_kernel_version() < (2, 6, 36):
             ignored_names.append('rlimit')
         if LINUX and get_kernel_version() < (2, 6, 23):
@@ -321,10 +321,8 @@ class TestSystemAPIs(unittest.TestCase):
     def test_pids(self):
         # Note: this test might fail if the OS is starting/killing
         # other processes in the meantime
-        pids_ps = ps("pid")
+        pids_ps = sorted(ps("pid"))
         pids_psutil = psutil.pids()
-        pids_ps.sort()
-        pids_psutil.sort()
 
         # on MACOS and OPENBSD ps doesn't show pid 0
         if MACOS or OPENBSD and 0 not in pids_ps:
