@@ -242,11 +242,11 @@ class TestSystemAPIs(unittest.TestCase):
             self.assertFalse(psutil.pid_exists(pid), msg=pid)
 
     def test_pids(self):
-        plist = [x.pid for x in psutil.process_iter()]
-        pidlist = psutil.pids()
-        self.assertEqual(plist.sort(), pidlist.sort())
+        pidslist = psutil.pids()
+        procslist = [x.pid for x in psutil.process_iter()]
         # make sure every pid is unique
-        self.assertEqual(len(pidlist), len(set(pidlist)))
+        self.assertEqual(sorted(set(pidslist)), pidslist)
+        self.assertEqual(pidslist, procslist)
 
     def test_test(self):
         # test for psutil.test() function
@@ -318,11 +318,12 @@ class TestSystemAPIs(unittest.TestCase):
     def test_cpu_times_time_increases(self):
         # Make sure time increases between calls.
         t1 = sum(psutil.cpu_times())
-        time.sleep(0.1)
-        t2 = sum(psutil.cpu_times())
-        difference = t2 - t1
-        if not difference >= 0.05:
-            self.fail("difference %s" % difference)
+        stop_at = time.time() + 1
+        while time.time() < stop_at:
+            t2 = sum(psutil.cpu_times())
+            if t2 > t1:
+                return
+        self.fail("time remained the same")
 
     def test_per_cpu_times(self):
         # Check type, value >= 0, str().
@@ -521,11 +522,7 @@ class TestSystemAPIs(unittest.TestCase):
                     if err.errno not in (errno.EPERM, errno.EACCES):
                         raise
                 else:
-                    if SUNOS or TRAVIS:
-                        # on solaris apparently mount points can also be files
-                        assert os.path.exists(disk.mountpoint), disk
-                    else:
-                        assert os.path.isdir(disk.mountpoint), disk
+                    assert os.path.exists(disk.mountpoint), disk
             self.assertIsInstance(disk.fstype, str)
             self.assertIsInstance(disk.opts, str)
 
@@ -769,7 +766,9 @@ class TestSystemAPIs(unittest.TestCase):
 
         ls = psutil.cpu_freq(percpu=True)
         if TRAVIS and not ls:
-            return
+            raise self.skipTest("skipped on Travis")
+        if FREEBSD and not ls:
+            raise self.skipTest("returns empty list on FreeBSD")
 
         assert ls, ls
         check_ls([psutil.cpu_freq(percpu=False)])
